"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.traverseTable = exports.traverseDocstring = exports.traverseStep = exports.traverseElement = exports.traverseFeature = void 0;
const JSONTraverse_1 = require("../cucumber-generic/JSONTraverse");
function makeTags(tags) {
    return tags
        ? tags.map((tag) => {
            return { name: `@${tag}` };
        })
        : [];
}
function makeLine(location) {
    return parseInt(location.split(':')[1]);
}
function durationToMillis(duration) {
    return duration ? duration / 1000 : 0;
}
function makeGenericFeature(source) {
    const description = source.description ? source.description.join('\n') : '';
    const tags = makeTags(source.tags);
    return {
        uri: source.location.split(':')[0],
        id: '',
        line: makeLine(source.location),
        keyword: source.keyword,
        name: source.name,
        description,
        elements: source.elements,
        tags,
    };
}
function traverseFeature(feature, astMaker, newId, predictableSupportCode) {
    return JSONTraverse_1.traverseFeature(makeGenericFeature(feature), astMaker, newId, predictableSupportCode, traverseElement);
}
exports.traverseFeature = traverseFeature;
function traverseElement(element, astMaker, newId, predictableSupportCode) {
    if (element.type === 'background') {
        return;
    }
    const tags = element.tags
        ? makeTags(element.tags).map((tag) => JSONTraverse_1.traverseTag(tag, astMaker))
        : undefined;
    return astMaker.makeScenarioFeatureChild(newId(), makeLine(element.location), element.keyword, element.name, element.description, element.steps.map((step) => traverseStep(step, astMaker, newId, predictableSupportCode)), tags);
}
exports.traverseElement = traverseElement;
function traverseStep(step, astMaker, newId, predictableSupportCode) {
    const line = makeLine(step.location);
    const docstring = step.text ? traverseDocstring(step.text, astMaker) : null;
    const datatable = step.table ? traverseTable(step.table, astMaker) : null;
    const gherkinStep = astMaker.makeStep(newId(), line, `${step.keyword} `, step.name, docstring, datatable);
    if (gherkinStep && step.match) {
        predictableSupportCode.addPredictableStepDefinition(step.match.location, gherkinStep.id, step.result.status, durationToMillis(step.result.duration), step.result.error_message);
    }
    return gherkinStep;
}
exports.traverseStep = traverseStep;
function traverseDocstring(text, astMaker) {
    return astMaker.makeDocstring(null, text);
}
exports.traverseDocstring = traverseDocstring;
function traverseTable(table, astMaker) {
    const cells = [table.headings.map((head) => head)];
    for (const row of table.rows) {
        cells.push(row.map((cell) => cell));
    }
    return astMaker.makeDataTable(cells);
}
exports.traverseTable = traverseTable;
//# sourceMappingURL=JSONTraverse.js.map