"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.traverseDocString = exports.traverseStep = exports.traverseAfterHook = exports.traverseBeforeHook = exports.traverseElement = exports.traverseFeature = void 0;
const JSONTraverse_1 = require("../cucumber-ruby/JSONTraverse");
const JSONTraverse_2 = require("../cucumber-generic/JSONTraverse");
function durationToMillis(duration) {
    return duration ? duration / 1000000 : 0;
}
function traverseFeature(feature, astMaker, newId, predictableSupportCode) {
    return JSONTraverse_2.traverseFeature(feature, astMaker, newId, predictableSupportCode, traverseElement);
}
exports.traverseFeature = traverseFeature;
function traverseElement(element, astMaker, newId, predictableSupportCode) {
    const beforeHooks = [];
    const scenarioSteps = [];
    const afterHooks = [];
    let currentStepIs = 'before';
    for (const step of element.steps) {
        if (currentStepIs === 'before' && !step.hidden) {
            currentStepIs = 'scenario';
        }
        else if (currentStepIs === 'scenario' && step.hidden) {
            currentStepIs = 'after';
        }
        switch (currentStepIs) {
            case 'before': {
                beforeHooks.push(step);
                break;
            }
            case 'scenario': {
                scenarioSteps.push(step);
                break;
            }
            case 'after': {
                afterHooks.push(step);
                break;
            }
        }
    }
    const tags = element.tags ? element.tags.map((tag) => JSONTraverse_2.traverseTag(tag, astMaker)) : [];
    const featureChild = astMaker.makeScenarioFeatureChild(newId(), element.line, element.keyword, element.name, element.description, scenarioSteps.map((step) => traverseStep(step, astMaker, newId, predictableSupportCode)), tags);
    for (const hook of beforeHooks) {
        traverseBeforeHook(hook, featureChild.scenario, predictableSupportCode);
    }
    for (const hook of afterHooks) {
        traverseAfterHook(hook, featureChild.scenario, predictableSupportCode);
    }
    return featureChild;
}
exports.traverseElement = traverseElement;
function traverseBeforeHook(step, scenario, predictableSupportCode) {
    predictableSupportCode.addPredictableBeforeHook(step.match.location, scenario.id, step.result.status, durationToMillis(step.result.duration), step.result.error_message);
}
exports.traverseBeforeHook = traverseBeforeHook;
function traverseAfterHook(step, scenario, predictableSupportCode) {
    predictableSupportCode.addPredictableAfterHook(step.match.location, scenario.id, step.result.status, durationToMillis(step.result.duration), step.result.error_message);
}
exports.traverseAfterHook = traverseAfterHook;
function traverseStep(step, astMaker, newId, predictableSupportCode) {
    const stepArguments = step.arguments || [];
    const docStringArgument = stepArguments.find((arg) => arg.content);
    const docString = docStringArgument ? traverseDocString(docStringArgument, astMaker) : null;
    const datatableArgument = stepArguments.find((arg) => arg.rows);
    const datatable = datatableArgument ? JSONTraverse_1.traverseDataTable(datatableArgument.rows, astMaker) : null;
    const gherkinStep = astMaker.makeStep(newId(), step.line, step.keyword, step.name, docString, datatable);
    if (gherkinStep && step.match) {
        predictableSupportCode.addPredictableStepDefinition(step.match.location, gherkinStep.id, step.result.status, durationToMillis(step.result.duration), step.result.error_message);
    }
    return gherkinStep;
}
exports.traverseStep = traverseStep;
function traverseDocString(docString, astMaker) {
    return astMaker.makeDocstring(null, docString.content);
}
exports.traverseDocString = traverseDocString;
//# sourceMappingURL=JSONTraverse.js.map