"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const stream_1 = require("stream");
const SingleObjectWritableStream_1 = __importDefault(require("./stream/SingleObjectWritableStream"));
const JSONTransformStream_1 = __importDefault(require("./stream/JSONTransformStream"));
const fake_cucumber_1 = require("@cucumber/fake-cucumber");
const PredictableSupportCode_1 = __importDefault(require("./PredictableSupportCode"));
const gherkin_1 = require("@cucumber/gherkin");
const gherkin_utils_1 = require("@cucumber/gherkin-utils");
const create_meta_1 = __importDefault(require("@cucumber/create-meta"));
const message_streams_1 = require("@cucumber/message-streams");
const AstMaker_1 = __importDefault(require("./AstMaker"));
const detectImplementation_1 = __importDefault(require("./detectImplementation"));
const JSONTraverse_1 = __importDefault(require("./JSONTraverse"));
const makePredictableTestPlan_1 = __importDefault(require("./test-generation/makePredictableTestPlan"));
const util_1 = require("util");
const gherkinDocumentToSource_1 = __importDefault(require("../test/gherkinDocumentToSource"));
const package_json_1 = require("../package.json");
const asyncPipeline = util_1.promisify(stream_1.pipeline);
/**
 * This function is the main entry point when this tool is used as a library
 * (for example in a Web application)
 *
 * @param jsonReadable - a Readable stream containing vintage Cucumber JSON
 * @param messageWritable - a Writable stream where messages will be written
 * @param implementation - an explicit implementation, such as "behave", "javascript" or "ruby"
 */
function main(jsonReadable, messageWritable, implementation) {
    return __awaiter(this, void 0, void 0, function* () {
        const singleObjectWritable = new SingleObjectWritableStream_1.default();
        yield asyncPipeline(jsonReadable, new JSONTransformStream_1.default(), singleObjectWritable);
        const supportCode = new fake_cucumber_1.SupportCode();
        const predictableSupportCode = new PredictableSupportCode_1.default(supportCode);
        const query = new gherkin_utils_1.Query();
        const ndjsonStream = new message_streams_1.MessageToNdjsonStream();
        const gherkinEnvelopeStream = new stream_1.PassThrough({ objectMode: true });
        const astMaker = new AstMaker_1.default();
        const gherkinDocuments = singleObjectWritable.object.map((feature) => JSONTraverse_1.default(implementation || detectImplementation_1.default(feature), feature, astMaker, supportCode.newId, predictableSupportCode));
        const metaEnvelope = {
            meta: create_meta_1.default('@cucumber/json-to-messages', package_json_1.version, process.env),
        };
        gherkinEnvelopeStream.write(metaEnvelope);
        for (const gherkinDocument of gherkinDocuments) {
            const sourceEnvelope = {
                source: gherkinDocumentToSource_1.default(gherkinDocument),
            };
            gherkinEnvelopeStream.write(sourceEnvelope);
            const gherkinDocumentEnvelope = { gherkinDocument: gherkinDocument };
            gherkinEnvelopeStream.write(gherkinDocumentEnvelope);
            const pickles = gherkin_1.compile(gherkinDocument, gherkinDocument.uri, supportCode.newId);
            for (const pickle of pickles) {
                const pickleEnvelope = { pickle };
                gherkinEnvelopeStream.write(pickleEnvelope);
            }
        }
        gherkinEnvelopeStream.end();
        ndjsonStream.pipe(messageWritable);
        yield fake_cucumber_1.runCucumber(supportCode, gherkinEnvelopeStream, query, ndjsonStream, undefined, makePredictableTestPlan_1.default);
    });
}
exports.default = main;
//# sourceMappingURL=jsonToMessages.js.map