"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = __importDefault(require("assert"));
const AstMaker_1 = __importDefault(require("../src/AstMaker"));
describe('AstMaker', () => {
    const astMaker = new AstMaker_1.default();
    describe('.makeFeature', () => {
        it('transforms the line to a Location object', () => {
            const feature = astMaker.makeFeature(12, '', '', '', []);
            assert_1.default.strictEqual(feature.location.line, 12);
        });
    });
    describe('#makeBackgroundFeatureChild', () => {
        const child = astMaker.makeBackgroundFeatureChild(1, '', '', '', []);
        it('returns a child with a background', () => {
            assert_1.default(child.background);
        });
        it('returns a child without scenario', () => {
            assert_1.default(!child.scenario);
        });
        it('returns a child without rule', () => {
            assert_1.default(!child.rule);
        });
    });
    context('#makeScenarioFeatureChild', () => {
        const child = astMaker.makeScenarioFeatureChild('id', 1, '', '', '', [], []);
        it('returns a child without background', () => {
            assert_1.default(!child.background);
        });
        it('returns a child with a scenario', () => {
            assert_1.default(child.scenario);
        });
        it('returns a child without rule', () => {
            assert_1.default(!child.rule);
        });
        it('creates an ID for the scenario', () => {
            const child = astMaker.makeScenarioFeatureChild('id', 1, '', '', '', [], []);
            assert_1.default.strictEqual(child.scenario.id, 'id');
        });
    });
    describe('makeStep', () => {
        it('generates an ID for the step', () => {
            const step = astMaker.makeStep('id', 10, 'Given ', 'some context');
            assert_1.default.strictEqual(step.id, 'id');
        });
    });
});
//# sourceMappingURL=AstMakerTest.js.map