"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = __importDefault(require("assert"));
const messages = __importStar(require("@cucumber/messages"));
const ts_sinon_1 = require("ts-sinon");
const JSONTraverse_1 = require("../../src/cucumber-ruby/JSONTraverse");
const JSONTraverse_2 = require("../../src/cucumber-generic/JSONTraverse");
describe('traversing elements', () => {
    const simpleStep = {
        keyword: 'Given',
        name: ' some context',
        line: 10,
        match: {
            location: 'some/steps.rb:11',
        },
        result: {
            duration: 123,
            status: 'whatever',
        },
    };
    const background = {
        id: 'my-background',
        type: 'background',
        keyword: 'Background',
        name: '',
        description: 'This background doe not much stuff',
        line: 3,
        steps: [],
    };
    const scenario = {
        id: 'my-scenario',
        type: 'scenario',
        keyword: 'Scenario',
        name: 'My scenario',
        description: 'This is my first scenario',
        line: 5,
        steps: [simpleStep],
    };
    describe('traverseFeature', () => {
        const feature = {
            uri: 'path/to/some.feature',
            id: 'my-feature',
            line: 2,
            keyword: 'Feature',
            name: 'My feature',
            description: 'It does things and stuff',
            elements: [scenario],
        };
        const emptyFeature = {
            uri: 'path/to/empty.feature',
            id: 'empty-feature',
            line: 1,
            keyword: 'Feature',
            name: 'An empty feature',
            description: 'It does nothing',
            elements: [],
        };
        const multiBackgroundFeature = {
            uri: 'path/to/some.feature',
            id: 'my-feature',
            line: 2,
            keyword: 'Feature',
            name: 'My feature',
            description: 'It does things and stuff',
            elements: [background, background, background],
        };
        it('calls AstMaker.makeFeature', () => {
            const astMaker = ts_sinon_1.stubInterface();
            const predictableSupportCode = ts_sinon_1.stubInterface();
            JSONTraverse_2.traverseFeature(emptyFeature, astMaker, messages.IdGenerator.incrementing(), predictableSupportCode, JSONTraverse_1.traverseElement);
            assert_1.default.deepStrictEqual(astMaker.makeFeature.getCall(0).args, [
                1,
                'Feature',
                'An empty feature',
                'It does nothing',
                [],
                [],
            ]);
        });
        it('uses the result of AtMaker.makeFeatureChild to populate the children', () => {
            const featureChild = {
                scenario: {
                    id: 'whatever-scenario-id',
                    description: '',
                    keyword: 'Scenario',
                    tags: [],
                    steps: [],
                    name: 'Hello',
                    location: { line: 0, column: 0 },
                    examples: [],
                },
            };
            const supportCode = ts_sinon_1.stubInterface();
            const astMaker = ts_sinon_1.stubInterface();
            astMaker.makeScenarioFeatureChild.returns(featureChild);
            JSONTraverse_2.traverseFeature(feature, astMaker, messages.IdGenerator.incrementing(), supportCode, JSONTraverse_1.traverseElement);
            assert_1.default.deepStrictEqual(astMaker.makeFeature.getCall(0).args, [
                2,
                'Feature',
                'My feature',
                'It does things and stuff',
                [featureChild],
                [],
            ]);
        });
        it('calls AstMaker.makeGherkinDocument with the generated feature', () => {
            const gherkinFeature = {
                name: 'My awesome feature',
                description: '',
                keyword: 'Feature',
                tags: [],
                location: { line: 0, column: 0 },
                language: 'en',
                children: [],
            };
            const supportCode = ts_sinon_1.stubInterface();
            const astMaker = ts_sinon_1.stubInterface();
            astMaker.makeFeature.returns(gherkinFeature);
            JSONTraverse_2.traverseFeature(feature, astMaker, messages.IdGenerator.incrementing(), supportCode, JSONTraverse_1.traverseElement);
            assert_1.default.deepStrictEqual(astMaker.makeGherkinDocument.getCall(0).args, [
                'path/to/some.feature',
                gherkinFeature,
            ]);
        });
        it('does not traverse the backgrounds when replicated', () => {
            const astMaker = ts_sinon_1.stubInterface();
            const supportCode = ts_sinon_1.stubInterface();
            JSONTraverse_2.traverseFeature(multiBackgroundFeature, astMaker, messages.IdGenerator.incrementing(), supportCode, JSONTraverse_1.traverseElement);
            assert_1.default.ok(astMaker.makeBackgroundFeatureChild.calledOnce);
        });
    });
    describe('travereTag', () => {
        it('calls AstMaker.makeTag to create the message', () => {
            const astMaker = ts_sinon_1.stubInterface();
            JSONTraverse_2.traverseTag({ name: '@something', line: 1 }, astMaker);
            assert_1.default.deepStrictEqual(astMaker.makeTag.getCall(0).args, ['@something', 1]);
        });
    });
});
//# sourceMappingURL=JSONTraverseTest.js.map