"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = __importDefault(require("assert"));
const messages = __importStar(require("@cucumber/messages"));
const ts_sinon_1 = require("ts-sinon");
const JSONTraverse_1 = require("../../src/cucumber-ruby/JSONTraverse");
describe('traversing elements', () => {
    const simpleStep = {
        keyword: 'Given',
        name: ' some context',
        line: 10,
        match: {
            location: 'some/steps.rb:11',
        },
        result: {
            duration: 12300000,
            status: 'passed',
        },
    };
    const background = {
        id: 'my-background',
        type: 'background',
        keyword: 'Background',
        name: '',
        description: 'This background doe not much stuff',
        line: 3,
        steps: [],
    };
    const scenario = {
        id: 'my-scenario',
        type: 'scenario',
        keyword: 'Scenario',
        name: 'My scenario',
        description: 'This is my first scenario',
        line: 5,
        steps: [simpleStep],
    };
    describe('traverseFeature', () => {
        const feature = {
            uri: 'path/to/some.feature',
            id: 'my-feature',
            line: 2,
            keyword: 'Feature',
            name: 'My feature',
            description: 'It does things and stuff',
            elements: [scenario],
        };
        const emptyFeature = {
            uri: 'path/to/empty.feature',
            id: 'empty-feature',
            line: 1,
            keyword: 'Feature',
            name: 'An empty feature',
            description: 'It does nothing',
            elements: [],
        };
        const multiBackgroundFeature = {
            uri: 'path/to/some.feature',
            id: 'my-feature',
            line: 2,
            keyword: 'Feature',
            name: 'My feature',
            description: 'It does things and stuff',
            elements: [background, background, background],
        };
        it('calls AstMaker.makeFeature', () => {
            const astMaker = ts_sinon_1.stubInterface();
            const predictableSupportCode = ts_sinon_1.stubInterface();
            JSONTraverse_1.traverseFeature(emptyFeature, astMaker, messages.IdGenerator.incrementing(), predictableSupportCode);
            assert_1.default.deepEqual(astMaker.makeFeature.getCall(0).args, [
                1,
                'Feature',
                'An empty feature',
                'It does nothing',
                [],
                [],
            ]);
        });
        it('uses the result of AstMaker.makeFeatureChild to populate the children', () => {
            const gherkinScenario = {
                scenario: {
                    id: 'whatever-scenario-id',
                    description: '',
                    examples: [],
                    keyword: 'Scenario',
                    location: { line: 1 },
                    name: 'Whatever',
                    steps: [],
                    tags: [],
                },
            };
            const supportCode = ts_sinon_1.stubInterface();
            const astMaker = ts_sinon_1.stubInterface();
            astMaker.makeScenarioFeatureChild.returns(gherkinScenario);
            JSONTraverse_1.traverseFeature(feature, astMaker, messages.IdGenerator.incrementing(), supportCode);
            assert_1.default.deepEqual(astMaker.makeFeature.getCall(0).args, [
                2,
                'Feature',
                'My feature',
                'It does things and stuff',
                [gherkinScenario],
                [],
            ]);
        });
        it('calls AstMaker.makeGherkinDocument with the generated feature', () => {
            const gherkinFeature = {
                name: 'My awesome feature',
                keyword: 'Feature',
                children: [],
                description: '',
                language: 'en',
                location: { line: 1 },
                tags: [],
            };
            const supportCode = ts_sinon_1.stubInterface();
            const astMaker = ts_sinon_1.stubInterface();
            astMaker.makeFeature.returns(gherkinFeature);
            JSONTraverse_1.traverseFeature(feature, astMaker, messages.IdGenerator.incrementing(), supportCode);
            assert_1.default.deepStrictEqual(astMaker.makeGherkinDocument.getCall(0).args, [
                'path/to/some.feature',
                gherkinFeature,
            ]);
        });
        it('does not traverse the backgrounds when replicated', () => {
            const astMaker = ts_sinon_1.stubInterface();
            const supportCode = ts_sinon_1.stubInterface();
            JSONTraverse_1.traverseFeature(multiBackgroundFeature, astMaker, messages.IdGenerator.incrementing(), supportCode);
            assert_1.default.ok(astMaker.makeBackgroundFeatureChild.calledOnce);
        });
    });
    describe('traverseElement', () => {
        it('calls AstMaker.makeFeatureChild with the correct data', () => {
            const astMaker = ts_sinon_1.stubInterface();
            const supportCode = ts_sinon_1.stubInterface();
            JSONTraverse_1.traverseElement(background, astMaker, messages.IdGenerator.incrementing(), supportCode);
            assert_1.default.deepStrictEqual(astMaker.makeBackgroundFeatureChild.getCall(0).args, [
                3,
                'Background',
                '',
                'This background doe not much stuff',
                [],
            ]);
        });
        it('steps are created when intanciating the FeatureElement', () => {
            const step = {
                id: 'whatever-id',
                keyword: 'Given ',
                location: { line: 1 },
                text: 'whatever',
            };
            const supportCode = ts_sinon_1.stubInterface();
            const astMaker = ts_sinon_1.stubInterface();
            astMaker.makeStep.returns(step);
            JSONTraverse_1.traverseElement(scenario, astMaker, messages.IdGenerator.incrementing(), supportCode);
            assert_1.default.deepStrictEqual(astMaker.makeScenarioFeatureChild.getCall(0).args[5], [step]);
        });
        it('registers hook if available', () => {
            const child = {
                scenario: {
                    id: 'some-scenario-id',
                    description: '',
                    examples: [],
                    keyword: 'Scenario',
                    location: { line: 1 },
                    name: 'Whatever',
                    steps: [],
                    tags: [],
                },
            };
            const supportCode = ts_sinon_1.stubInterface();
            const astMaker = ts_sinon_1.stubInterface();
            astMaker.makeScenarioFeatureChild.returns(child);
            JSONTraverse_1.traverseElement({
                before: [
                    {
                        match: {
                            location: 'some/steps.rb:2',
                        },
                        result: {
                            status: 'passed',
                            duration: 12300,
                        },
                    },
                ],
                id: 'my-scenario',
                type: 'scenario',
                keyword: 'Scenario',
                name: 'My scenario',
                description: 'This is my first scenario',
                line: 5,
                steps: [simpleStep],
                after: [
                    {
                        match: {
                            location: 'some/steps.rb:12',
                        },
                        result: {
                            status: 'failed',
                            duration: 123000,
                            error_message: 'This has failed',
                        },
                    },
                ],
            }, astMaker, messages.IdGenerator.incrementing(), supportCode);
            assert_1.default.deepEqual(supportCode.addPredictableBeforeHook.getCall(0).args, [
                'some/steps.rb:2',
                child.scenario.id,
                'passed',
                0.0123,
                undefined,
            ]);
            assert_1.default.deepEqual(supportCode.addPredictableAfterHook.getCall(0).args, [
                'some/steps.rb:12',
                child.scenario.id,
                'failed',
                0.123,
                'This has failed',
            ]);
        });
    });
    describe('traverseStep', () => {
        const docStringStep = {
            keyword: 'Given',
            name: ' some context',
            line: 10,
            match: {
                location: 'some/steps.rb:11',
            },
            result: {
                duration: 123,
                status: 'whatever',
            },
            docString: {
                content_type: 'text/markdown',
                value: '# This is a title',
            },
        };
        const datatableStep = {
            keyword: 'Given',
            name: ' some context',
            line: 10,
            match: {
                location: 'some/steps.rb:11',
            },
            result: {
                duration: 123,
                status: 'whatever',
            },
            rows: [
                {
                    cells: ['a', 'b', 'c'],
                },
            ],
        };
        it('calls AstMaker.makeStep', () => {
            const astMaker = ts_sinon_1.stubInterface();
            const supportCode = ts_sinon_1.stubInterface();
            JSONTraverse_1.traverseStep(simpleStep, astMaker, () => 'the-id', supportCode);
            assert_1.default.deepEqual(astMaker.makeStep.getCall(0).args, [
                'the-id',
                10,
                'Given',
                ' some context',
                null,
                null,
            ]);
        });
        it('passes on docstring is available', () => {
            const astMaker = ts_sinon_1.stubInterface();
            const supportCode = ts_sinon_1.stubInterface();
            JSONTraverse_1.traverseStep(docStringStep, astMaker, messages.IdGenerator.incrementing(), supportCode);
            assert_1.default.notStrictEqual(astMaker.makeStep.getCall(0).args[3], null);
        });
        it('passes on datatable is available', () => {
            const astMaker = ts_sinon_1.stubInterface();
            const supportCode = ts_sinon_1.stubInterface();
            JSONTraverse_1.traverseStep(datatableStep, astMaker, () => 'the-id', supportCode);
            assert_1.default.notStrictEqual(astMaker.makeStep.getCall(0).args[5], null);
        });
        it('registers a stepDefinition using supportCode', () => {
            const step = {
                id: 'some-step-id',
                keyword: 'Given ',
                location: { line: 1 },
                text: 'whatever',
            };
            const supportCode = ts_sinon_1.stubInterface();
            const astMaker = ts_sinon_1.stubInterface();
            astMaker.makeStep.returns(step);
            JSONTraverse_1.traverseStep(simpleStep, astMaker, messages.IdGenerator.incrementing(), supportCode);
            assert_1.default.deepStrictEqual(supportCode.addPredictableStepDefinition.getCall(0).args, [
                'some/steps.rb:11',
                step.id,
                'passed',
                12.3,
                undefined,
            ]);
        });
        it('does not register stepDefinition when a step has no match', () => {
            const step = {
                id: 'some-step-id',
                keyword: 'Given ',
                location: { line: 1 },
                text: 'whatever',
            };
            const supportCode = ts_sinon_1.stubInterface();
            const astMaker = ts_sinon_1.stubInterface();
            astMaker.makeStep.returns(step);
            JSONTraverse_1.traverseStep({
                keyword: 'Given',
                name: 'an undefined step',
                line: 10,
                result: {
                    status: 'undefined',
                },
            }, astMaker, messages.IdGenerator.incrementing(), supportCode);
            assert_1.default.strictEqual(supportCode.addPredictableStepDefinition.callCount, 0);
        });
        it('does not register stepDefinition when a step has an empty match', () => {
            const step = {
                id: 'some-step-id',
                keyword: 'Given ',
                location: { line: 1 },
                text: 'whatever',
            };
            const supportCode = ts_sinon_1.stubInterface();
            const astMaker = ts_sinon_1.stubInterface();
            astMaker.makeStep.returns(step);
            JSONTraverse_1.traverseStep({
                keyword: 'Given',
                name: 'an undefined step',
                line: 10,
                result: {
                    status: 'undefined',
                },
                match: {
                    location: undefined,
                },
            }, astMaker, messages.IdGenerator.incrementing(), supportCode);
            assert_1.default.strictEqual(supportCode.addPredictableStepDefinition.callCount, 0);
        });
    });
    describe('traverseDocString', () => {
        const docString = {
            content_type: 'text/plain',
            value: 'Some random content',
        };
        it('calls AstMaker.makeDocString', () => {
            const astMaker = ts_sinon_1.stubInterface();
            JSONTraverse_1.traverseDocString(docString, astMaker);
            assert_1.default.strictEqual(astMaker.makeDocstring.callCount, 1);
        });
    });
    describe('traverseDataTable', () => {
        const dataTable = [
            {
                cells: ['username', 'password'],
            },
            {
                cells: ['admin', '@dmin'],
            },
            {
                cells: ['user', 's3cr3t'],
            },
        ];
        it('calls AstMaker.makeDataTable', () => {
            const astMaker = ts_sinon_1.stubInterface();
            JSONTraverse_1.traverseDataTable(dataTable, astMaker);
            assert_1.default.deepEqual(astMaker.makeDataTable.getCall(0).args[0], [
                ['username', 'password'],
                ['admin', '@dmin'],
                ['user', 's3cr3t'],
            ]);
        });
    });
});
//# sourceMappingURL=JSONTraverseTest.js.map