"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = __importDefault(require("assert"));
const detectImplementation_1 = __importDefault(require("../src/detectImplementation"));
describe('detectImplementation', () => {
    it('defaults to "ruby"', () => {
        const feature = {};
        assert_1.default.strictEqual(detectImplementation_1.default(feature), 'cucumber-ruby');
    });
    context('when the feature has a status field', () => {
        it('returns "behave"', () => {
            const feature = {
                status: 'passed',
            };
            assert_1.default.strictEqual(detectImplementation_1.default(feature), 'behave');
        });
    });
    context('when the feature has a location field', () => {
        it('returns "behave"', () => {
            const feature = {
                location: 'my/wonderful.feature:3',
            };
            assert_1.default.strictEqual(detectImplementation_1.default(feature), 'behave');
        });
    });
    context('when a step has an "hidden" field', () => {
        it('returns "javascript"', () => {
            const steps = [
                {},
                {
                    hidden: true,
                },
            ];
            const elements = [
                {
                    steps,
                },
            ];
            const feature = {
                elements,
            };
            assert_1.default.strictEqual(detectImplementation_1.default(feature), 'cucumber-js');
        });
    });
    context('when a step has an "arguments" field', () => {
        it('returns "javascript"', () => {
            const args = [];
            const steps = [
                {},
                {
                    arguments: args,
                },
            ];
            const elements = [
                {
                    steps,
                },
            ];
            const feature = {
                elements,
            };
            assert_1.default.strictEqual(detectImplementation_1.default(feature), 'cucumber-js');
        });
    });
});
//# sourceMappingURL=detectImplementationTest.js.map