"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const stream_1 = require("stream");
const util_1 = require("util");
const assert_1 = __importDefault(require("assert"));
const JSONTransformStream_1 = __importDefault(require("../../src/stream/JSONTransformStream"));
const SingleObjectWritableStream_1 = __importDefault(require("../../src/stream/SingleObjectWritableStream"));
const asyncPipeline = util_1.promisify(stream_1.pipeline);
describe('JSONReportStream', () => {
    it('transforms a readable stream to a JSON report', () => __awaiter(void 0, void 0, void 0, function* () {
        const data = [{}, {}, {}];
        const readableStream = new stream_1.Stream.Readable({
            read() {
                this.push(JSON.stringify(data));
                this.push(null);
            },
        });
        const sink = new SingleObjectWritableStream_1.default();
        yield asyncPipeline(readableStream, new JSONTransformStream_1.default(), sink);
        assert_1.default.deepStrictEqual(sink.object, data);
    }));
    it('handles non-json data gracefully', () => __awaiter(void 0, void 0, void 0, function* () {
        const data = '# this is not json';
        const readableStream = new stream_1.Stream.Readable({
            read() {
                this.push(data);
                this.push(null);
            },
        });
        const sink = new SingleObjectWritableStream_1.default();
        let f = () => null;
        try {
            yield asyncPipeline(readableStream, new JSONTransformStream_1.default(), sink);
        }
        catch (e) {
            f = () => {
                throw e;
            };
        }
        finally {
            assert_1.default.throws(f, /SyntaxError.+JSON/);
        }
    }));
});
//# sourceMappingURL=JSONTransformStreamTest.js.map